<!--- 
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.

The Original Code is comprised of the PT Calendar directory

The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2012.
All Rights Reserved.

By downloading, modifying, distributing, using and/or accessing any files 
in this directory, you agree to the terms and conditions of the applicable 
end user license agreement.
--->
<!---
/* *************************************************************** */
Author: 	
	PaperThin Inc.
	G. Cronkright
Name:
	category_checkbox_list_calendar_rh.cfm
Summary:
	Render Handler to render out the category checkboxes for the calendar views
ADF App:
	pt_calendar
Version:
	3.0.0
History:
	2011-08-17 - GAC - Created
--->

<cfscript>
	// This script MUST remain dynamic since the generated HTML is modified with a URL parameters
	request.element.isStatic = 0;
	
	items = attributes.elementInfo.elementData.propertyValues;
	
	// Set Category Check display default
	showCategoryCheckboxes = true;
	
	// Check to see if we are in a single veiw displaying the event details... if so... do NOT show the category checkboxes
	viewParamName = application.ptCalendar.viewParamName;
	if ( application.ptCalendar.viewPageMode EQ "Single" ) { 
		if ( StructKeyExists(request.params,viewParamName) AND request.params[viewParamName] EQ "eventdetails" )
			showCategoryCheckboxes = false;
	}
	
	classParentPrefix = application.ptCalendar.getCatParentItemPrefix(); 	//"catParent-";
	classItemPrefix = application.ptCalendar.getCatItemPrefix(); 			//"catType-";
	
	/* Calendar Styles  -  General */
	calendarClass = "calendarWrapper";
	eventLayerClass = "calEventLayer";
	
	/* LIST Styles */
	listEventHeader = "calEventListHeader";
	
	listEventDayClass = "month-list-day-event";
	listStandardDayClass = "month-list-day-standard";
	listCurrentDayClass = "month-list-day-current";
	
	/* GRID Styles */
	gridDayCellClass = "calEventDayCell";
	
	gridMonthEventDayClass = "month-grid-day-event";
	gridMonthStandardDayClass = "month-grid-day-standard";
	gridMonthCurrentDayClass = "month-grid-day-current";
	
	gridWeekEventDayClass = "week-grid-day-event";
	gridWeekStandardDayClass = "week-grid-day-standard";
	gridWeekCurrentDayClass = "week-grid-day-current";
	
	eventCatListIconClass = "calCatListIcon";
	
	application.ptCalendar.scripts.loadJQuery();
	application.ptCalendar.scripts.loadJQueryUI();
	application.ptCalendar.scripts.loadCFJS();
	application.ptCalendar.scripts.loadJqueryCheckboxes();
	application.ptCalendar.scripts.loadJqueryCookie();
</cfscript>
<!--- <cfdump var="#items#" label="items" expand="false" /> --->

<cfif ArrayLen(items) AND showCategoryCheckboxes>
<cfoutput>
	<script type="text/javascript">
		jQuery(function(){
			// Add the button style to the Save and Publish buttons
			jQuery("##calCatCheckAll").button();
			jQuery("##calCatUncheckAll").button();	
				
			//var allParentCats = buildAllParentClassList(); 
			//jQuery('.#calendarClass#').attr("class","#calendarClass# " + allParentCats);
			//console.log("Cookie (onload): " + jQuery.cookie("selectedCategories"));
		
			if ( jQuery.cookie("selectedCategories") ) {
				// check saved Checkboxes when page reloads if a cookie is found	
				updateSelectedCats();
				updateSelectedEvents();
			} 
			else {
				// check all Checkboxes when page reloads (if no cookie is found)
				checkAllCheckBoxes();
			}
			
			// when a Cat is checked or unchecked do work!
			jQuery(".catChkBox").click(function(){
				updateSelectedEvents();
			});
			
			// Check All Checkboxes and Show all events
			jQuery("##calCatCheckAll").click(function(){
				checkAllCheckBoxes();
			});
			
			// Uncheck All Checkboxes and Hide all events
			jQuery("##calCatUncheckAll").click(function(){
				uncheckAllCheckBoxes();
			});
		});
		
		// Function to handle unchecking All Checkboxes and Hiding all categorized all events
		function uncheckAllCheckBoxes() {
			jQuery("##eventTypeForm").unCheckCheckboxes();
			updateSelectedEvents();
		}

		// Function to handle checking All Checkboxes and Showing categorized all events
		function checkAllCheckBoxes() {
			jQuery("##eventTypeForm").checkCheckboxes();
			updateSelectedEvents();
		}

		function updateSelectedCats(){
			var selectedCats = jQuery.cookie("selectedCategories");
			var selectedCatArray = selectedCats.split(" ");
			//console.log("cookie: " + selectedCats);
			
			// Uncheck all options to start from scratch
			jQuery(".catChkBox").unCheckCheckboxes();
			
			// Now check the cats stored in the cookie
			jQuery(selectedCatArray).each(function(index,item){
				jQuery(".catChkBox[value='" + item + "']").attr("checked","checked");
			});	
		}
		
		function buildAllParentClassList(){
			var parentNameList = "";
			var parentValue = "";
			// Rebuild the Parent Class String from the checked categories
			jQuery('.catChkBox').each(function(index,item){
				parentValue = jQuery(item).val();
				if ( jQuery.FindNoCase("#classItemPrefix#",parentValue) )
				{
					checkedParentValue = jQuery.Replace(parentValue,"#classItemPrefix#","#classParentPrefix#","one");
					parentNameList=jQuery.ListAppend(parentNameList,parentValue," ");
				}
			});
			parentNameList=jQuery.trim(parentNameList);
			return parentNameList;	
		}
		
		function buildParentClassList(){
			var parentNameList = "";
			var checkedParentValue = "";
			// Rebuild the Parent Class String from the checked categories
			jQuery('.catChkBox:checked').each(function(index,item){
				checkedParentValue = jQuery(item).val();
				if ( jQuery.FindNoCase("#classItemPrefix#",checkedParentValue) )
				{
					//checkedParentValue = jQuery.Replace(checkedParentValue,"#classItemPrefix#","","one");
					//checkedParentValue = "#classParentPrefix#" + checkedParentValue;
					checkedParentValue = jQuery.Replace(checkedParentValue,"#classItemPrefix#","#classParentPrefix#","one");
					//parentNameList=parentNameList + " " + checkedParentValue;
					parentNameList=jQuery.ListAppend(parentNameList,checkedParentValue," ");
				}
			});
			parentNameList=jQuery.trim(parentNameList);
			return parentNameList;	
		}

		function buildChildClassList(){
			var childNameList = "";
			var checkedChildValue = "";
			// Rebuild the Class String from the checked categories
			jQuery('.catChkBox:checked').each(function(index,item){
				checkedChildValue = jQuery(item).val();
				//console.log(checkedCatValue);
				//childNameList=childNameList + " " + checkedChildValue;
				childNameList=jQuery.ListAppend(childNameList,checkedChildValue," ");
			});
			childNameList=jQuery.trim(childNameList);
			return childNameList;	
		}
		
		// Sub-function for working with Day Headers on Calendar List Views 
		function showHideParentDIVs(){
			<!--- // TODO: List handling, this really should be done elsewhere using css... This has the potential to be slow.  --->
			// Get the Events List header and determine if they should be shown or hidden
			jQuery("div.#listEventHeader#").each(function(index,headerElement){ 
				var showHeaderAndEvents = false;
				var headerParentObj = jQuery(headerElement).parent();
				var childArray = jQuery(headerElement).siblings().find('div.#eventLayerClass#');
				// Start with all Parent Object Shown... and then hide them as needed 
				headerParentObj.show();
				// Loop over the child node and set to show... if all events for this day are not visible
				jQuery.each(childArray, function(cIndex, childElement){
					var childStatus = jQuery(childElement).is(":visible");
					// if an calEventLayer DIV is visible (stop the loop and show the date Header)
					if ( childStatus ) {
						showHeaderAndEvents = true;
						return false; 
					}
				}); 
				// Hide the header and the events if needed	
				if ( !showHeaderAndEvents )
					headerParentObj.hide();
			});	
		}
		
		// Sub-function for working with Cell Styles on Calendar Grid Views 
		function updateParentStyle(){
			var eventClass = "#gridMonthEventDayClass#";	
			var standardClass = "#gridMonthStandardDayClass#";
				
			//console.log("modify the event cell's style");
			
			// Get the Cells with Events and determine if they should be have the event style or not
			jQuery("td.#gridDayCellClass#").each(function(index,cellElement){ 
				var addEventsStyle = false;
				var childArray = jQuery(cellElement).children().find('div.#eventLayerClass#');
				//console.log(cellElement);
				//console.log(childArray);
				
				if ( jQuery(cellElement).attr("class").match(/week-grid/) )
				{
					eventClass = "#gridWeekEventDayClass#";	
					standardClass = "#gridWeekStandardDayClass#";
				}
				//console.log(eventClass);
				//console.log(standardClass);
				
				// Start with all days with events with eventClass and then remove the eventClass as needed
				jQuery(cellElement).attr("class","#gridDayCellClass# " + eventClass);
				//jQuery(cellElement).removeClass(standardClass).addClass(eventClass);
				
				// Loop over the child node and set to event style ... if all events for this day are not visible
				jQuery.each(childArray, function(cIndex, childElement){
					var childStatus = jQuery(childElement).is(":visible");
					// if an calEventLayer DIV is visible (stop the loop and show the date Header)
					if ( childStatus ) 
					{
						addEventsStyle = true;
						return false; 
					}
				});
				// Update the Cell Style if needed
				if ( !addEventsStyle )
					jQuery(cellElement).attr("class","#gridDayCellClass# " + standardClass);
					//jQuery(cellElement).removeClass(standardClass).addClass(eventClass);	
			});
		}

		function updateSelectedEvents(){	
			//var rootClassName = "#calendarClass#";  
			var parentClassNames = buildParentClassList();
			var childClassNames = buildChildClassList();
			
			// Replace the rebuilt Parent class list string on the Parent DIV
			jQuery('.#calendarClass#').attr("class","#calendarClass# " + parentClassNames);
			
			// All Cats are unchecked... set cookie to 'none'
			if ( jQuery.trim(childClassNames).length <= 0 )
				jQuery.cookie("selectedCategories",'none', { expires: 30 });
			else
				jQuery.cookie("selectedCategories",childClassNames, { expires: 30 });	
			//console.log("New Cookie: " + jQuery.cookie("selectedCategories"));
			
			// Only do the showHideParentDIVs() on list calendar views
 			childrenArray = jQuery('.#calendarClass#')
 									.children()
 									.filter(function(){
								        return jQuery(this).attr("class").match(/list-wrapper/);
								    });						    
 			//console.log(childrenArray);
 			
 			// if 'list-wrapper' is found do showHideParentDIVs() else updateParentStyle()
 			if ( childrenArray.length )
				showHideParentDIVs();
			else
				updateParentStyle();
		}
	</script>
	
	<style type="text/css">
		/* .calEventLayer {
			display: none;
		} */
		
		<!--- // Loop over all of the Categories to generate the styles --->
		<cfloop from="1" to="#arrayLen(items)#" index="itm">
			<cfif StructKeyExists(items[itm],"values") AND StructKeyExists(items[itm].values,"catid")>
			<!--- <cfset parentValue = classParentPrefix & items[itm].values.catid> --->
			<cfset parentValue = classParentPrefix & application.ptCalendar.calRenderService.stripEventTypeChars(items[itm].values.catid)>
			<!--- <cfset childValue = classItemPrefix & items[itm].values.catid> --->
			<cfset childValue = classItemPrefix & application.ptCalendar.calRenderService.stripEventTypeChars(items[itm].values.catid)>
			/* Parent DIV and Child DIV combination */
			.#parentValue# .#childValue#{
				display: block;
			}
			/* Child with no Parent  */
			.#childValue#{
				display: none;
			}
			</cfif>
		</cfloop>
	</style>
	
	<div class="categories-form">
		<form action="javascript:;" method="post" id="eventTypeForm" name="eventTypeForm">
		<!--- // Loop over all of the Categories to generate the Checkboxes --->
		<cfloop from="1" to="#arrayLen(items)#" index="itm">
			<cfset iconImgStr = "">
			<cfset iconStruct = StructNew()>
			<cfset checkBoxValue = "">
			<cfset checkBoxName = "">
			<!--- // Get the Values from the element  --->
			<cfif StructKeyExists(items[itm],"values")>
				<cfif StructKeyExists(items[itm].values,"catid")>
					<!--- <cfset checkBoxValue = classItemPrefix & items[itm].values.catid> --->
					<cfset checkBoxValue = classItemPrefix & application.ptCalendar.calRenderService.stripEventTypeChars(items[itm].values.catid)>
				</cfif>
				<cfif StructKeyExists(items[itm].values,"name")>
					<cfset checkBoxName = items[itm].values.name>
				</cfif>
				<cfif StructKeyExists(items[itm].values,"categoryIcon")>
					<cfset iconStruct = items[itm].values.categoryIcon>
				</cfif>
			</cfif>
			<!--- // Parse the Image Icon --->
			<cfif IsStruct(iconStruct) AND structKeyExists(iconStruct,"RESOLVEDURL") AND structKeyExists(iconStruct.RESOLVEDURL,"SERVERRELATIVE")>
				<cfsavecontent variable="iconImgStr">
				<img src="#iconStruct.RESOLVEDURL.SERVERRELATIVE#" border="0" alt="" class="#eventCatListIconClass#" /> <!--- class="eventCatIcon"  --->
				</cfsavecontent>
			</cfif>
			<!--- // Generate the Checkbox --->
			<cfif LEN(TRIM(checkBoxValue)) AND LEN(TRIM(checkBoxName))>
				<!--- <cfset checkBoxValue = classItemPrefix & application.ptCalendar.calRenderService.stripEventTypeChars(items[itm].values.catid)> --->
				<input type="checkbox" name="categories" id="#itm#_cat" value="#checkBoxValue#" class="catChkBox"><label for="#itm#_cat"> #checkBoxName#<cfif LEN(TRIM(iconImgStr))> #iconImgStr#</cfif></label><br />
			</cfif>
		</cfloop>
			<br />
			<!--- // Generate the check ALL or check NONE buttons --->
			<input type="button" name="calCatCheckAll" id="calCatCheckAll" value="Check All" class="categories-form-button" />
			<input type="button" name="calCatUncheckAll" id="calCatUncheckAll" value="Uncheck All" class="categories-form-button" />
		</form>
	</div>
</cfoutput>
</cfif>